@@ -46,8 +46,6 @@
 #include "curl_socket.h"
 #include "curl_stack.h"
 
-namespace std { using namespace tr1; }
-
 namespace core {
 
 CurlStack::CurlStack() :
@@ -57,7 +55,7 @@ CurlStack::CurlStack() :
   m_ssl_verify_peer(true),
   m_dns_timeout(60) {
 
-  m_taskTimeout.set_slot(rak::mem_fn(this, &CurlStack::receive_timeout));
+  m_taskTimeout.slot() = std::tr1::bind(&CurlStack::receive_timeout, this);
 
 #if (LIBCURL_VERSION_NUM >= 0x071000)
   curl_multi_setopt((CURLM*)m_handle, CURLMOPT_TIMERDATA, this);
