@@ -71,13 +71,9 @@
 #include "download_store.h"
 #include "http_queue.h"
 #include "manager.h"
-#include "poll_manager_epoll.h"
-#include "poll_manager_kqueue.h"
-#include "poll_manager_select.h"
+#include "poll_manager.h"
 #include "view.h"
 
-namespace std { using namespace tr1; }
-
 namespace core {
 
 void
@@ -107,47 +103,48 @@ Manager::handshake_log(const sockaddr* sa, int msg, int err, const torrent::Hash
 
   switch (msg) {
   case torrent::ConnectionManager::handshake_incoming:
-    m_logComplete.push_front("Incoming connection from " + peer + download);
+    push_log_complete("Incoming connection from " + peer + download);
     break;
   case torrent::ConnectionManager::handshake_outgoing:
-    m_logComplete.push_front("Outgoing connection to " + peer + download);
+    push_log_complete("Outgoing connection to " + peer + download);
     break;
   case torrent::ConnectionManager::handshake_outgoing_encrypted:
-    m_logComplete.push_front("Outgoing encrypted connection to " + peer + download);
+    push_log_complete("Outgoing encrypted connection to " + peer + download);
     break;
   case torrent::ConnectionManager::handshake_outgoing_proxy:
-    m_logComplete.push_front("Outgoing proxy connection to " + peer + download);
+    push_log_complete("Outgoing proxy connection to " + peer + download);
     break;
   case torrent::ConnectionManager::handshake_success:
-    m_logComplete.push_front("Successful handshake: " + peer + download);
+    push_log_complete("Successful handshake: " + peer + download);
     break;
   case torrent::ConnectionManager::handshake_dropped:
-    m_logComplete.push_front("Dropped handshake: " + peer + " - " + torrent::strerror(err) + download);
+    push_log_complete("Dropped handshake: " + peer + " - " + torrent::strerror(err) + download);
     break;
   case torrent::ConnectionManager::handshake_failed:
-    m_logComplete.push_front("Handshake failed: " + peer + " - " + torrent::strerror(err) + download);
+    push_log_complete("Handshake failed: " + peer + " - " + torrent::strerror(err) + download);
     break;
   case torrent::ConnectionManager::handshake_retry_plaintext:
-    m_logComplete.push_front("Trying again without encryption: " + peer + download);
+    push_log_complete("Trying again without encryption: " + peer + download);
     break;
   case torrent::ConnectionManager::handshake_retry_encrypted:
-    m_logComplete.push_front("Trying again encrypted: " + peer + download);
+    push_log_complete("Trying again encrypted: " + peer + download);
     break;
   default:
-    m_logComplete.push_front("Unknown handshake message for " + peer + download);
+    push_log_complete("Unknown handshake message for " + peer + download);
     break;
   }
 }
 
 void
 Manager::push_log(const char* msg) {
-  m_logImportant.push_front(msg);
-  m_logComplete.push_front(msg);
+  m_log_important->lock_and_push_log(msg, strlen(msg), 0);
+  m_log_complete->lock_and_push_log(msg, strlen(msg), 0);
 }
 
 Manager::Manager() :
-  m_hashingView(NULL)
-//   m_pollManager(NULL) {
+  m_hashingView(NULL),
+  m_log_important(torrent::log_open_log_buffer("important")),
+  m_log_complete(torrent::log_open_log_buffer("complete"))
 {
   m_downloadStore   = new DownloadStore();
   m_downloadList    = new DownloadList();
@@ -164,6 +161,8 @@ Manager::~Manager() {
   torrent::Throttle::destroy_throttle(m_throttles["NULL"].first);
   delete m_downloadList;
 
+  // TODO: Clean up logs objects.
+
   delete m_downloadStore;
   delete m_httpQueue;
   delete m_fileStatusCache;
@@ -206,7 +205,7 @@ Manager::get_address_throttle(const sockaddr* addr) {
 // Most of this should be possible to move out.
 void
 Manager::initialize_second() {
-  torrent::Http::set_factory(std::bind(&CurlStack::new_object, m_httpStack));
+  torrent::Http::slot_factory() = std::tr1::bind(&CurlStack::new_object, m_httpStack);
   m_httpQueue->slot_factory(sigc::mem_fun(m_httpStack, &CurlStack::new_object));
 
   CurlStack::global_init();
@@ -373,8 +372,7 @@ Manager::set_proxy_address(const std::string& addr) {
 
 void
 Manager::receive_http_failed(std::string msg) {
-  m_logImportant.push_front("Http download error: \"" + msg + "\"");
-  m_logComplete.push_front("Http download error: \"" + msg + "\"");
+  push_log_std("Http download error: \"" + msg + "\"");
 }
 
 void
