@@ -38,9 +38,10 @@
 #define RTORRENT_INPUT_BINDINGS_H
 
 #include <map>
-#include <ncurses.h>
 #include <sigc++/functors/slot.h>
 
+#include "display/attributes.h"
+
 namespace input {
 
 class Bindings : private std::map<int, sigc::slot0<void> > {
