@@ -47,9 +47,7 @@
 #include <torrent/data/file_list_iterator.h>
 
 // Move into config.h or something.
-namespace std {
-  using namespace tr1;
-}
+namespace tr1 { using namespace std::tr1; }
 
 namespace core {
   class Download;
@@ -113,7 +111,7 @@ typedef rt_triple<int, void*, void*> target_type;
 class command_base;
 
 typedef const torrent::Object (*command_base_call_type)(command_base*, target_type, const torrent::Object&);
-typedef std::function<torrent::Object (target_type, const torrent::Object&)> base_function;
+typedef tr1::function<torrent::Object (target_type, const torrent::Object&)> base_function;
 
 template <typename tmpl> struct command_base_is_valid {};
 template <command_base_call_type tmpl_func> struct command_base_is_type {};
@@ -210,9 +208,16 @@ protected:
   // within commands. E.d. callable command strings where one of the
   // arguments within the command needs to be supplied by the caller.
 
+#ifdef HAVE_CXX11
+  union {
+    base_function t_pod;
+    // char t_pod[sizeof(base_function)];
+  };
+#else
   union {
     char t_pod[sizeof(base_function)];
   };
+#endif
 };
 
 template <typename T1 = void, typename T2 = void>
@@ -245,7 +250,7 @@ command_base::_call(command_base* cmd, target_type target, Args args) {
 }
 
 #define COMMAND_BASE_TEMPLATE_TYPE(func_type, func_parm)                \
-  template <typename T, int proper = target_type_id<T>::proper_type> struct func_type { typedef std::function<func_parm> type; }; \
+  template <typename T, int proper = target_type_id<T>::proper_type> struct func_type { typedef tr1::function<func_parm> type; }; \
                                                                         \
   template <> struct command_base_is_valid<func_type<target_type>::type>                { static const int value = 1; }; \
   template <> struct command_base_is_valid<func_type<core::Download*>::type>            { static const int value = 1; }; \
